@@ -2,14 +2,17 @@
 # Copyright 2013 Christoph Reiter
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 import re
 
+from quodlibet import _
 from quodlibet import util
 from quodlibet.qltk.models import ObjectStore
 from quodlibet.util.collection import Collection
+from quodlibet.compat import iteritems, listfilter
 
 
 class BaseEntry(Collection):
@@ -19,7 +22,7 @@ class BaseEntry(Collection):
 
         self.songs = set(songs or [])
         self.key = key # not used for sorting!
-        self.sort = ""
+        self.sort = tuple()
 
     def all_have(self, tag, value):
         """Check if all songs have tag `tag` set to `value`"""
@@ -78,7 +81,7 @@ class SongsEntry(BaseEntry):
 class UnknownEntry(SongsEntry):
 
     def __init__(self, songs=None):
-        super(UnknownEntry, self).__init__("", "", songs)
+        super(UnknownEntry, self).__init__("", tuple(), songs)
 
     def get_text(self, config):
         return True, "<b>%s</b>" % _("Unknown")
@@ -124,7 +127,7 @@ class PaneModel(ObjectStore):
             return self.__key_cache[song]
         except KeyError:
             # We filter out empty values, so Unknown can be ""
-            self.__key_cache[song] = filter(
+            self.__key_cache[song] = listfilter(
                 lambda v: v[0], self.config.format(song))
             return self.__key_cache[song]
 
@@ -224,7 +227,7 @@ class PaneModel(ObjectStore):
                     collection[key] = (entry, hsort, bool(sort))
                     entry.songs.add(song)
 
-        items = sorted(collection.iteritems(),
+        items = sorted(iteritems(collection),
                        key=lambda s: s[1][1],
                        reverse=True)
 
