@@ -4,8 +4,9 @@
 #           2014 Christoph Reiter
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 import os
 
@@ -44,7 +45,7 @@ class CommandRegistry(object):
         Args:
             name (str): the command name
             args (int): amount of required arguments
-            optional (int): amoutn of additional optional arguments
+            optional (int): amount of additional optional arguments
         Returns:
             Callable
         """
@@ -144,18 +145,12 @@ def _pause(app):
 
 @registry.register("play")
 def _play(app):
-    player = app.player
-    if player.song:
-        player.paused = False
+    app.player.play()
 
 
 @registry.register("play-pause")
 def _play_pause(app):
-    player = app.player
-    if player.song is None:
-        player.reset()
-    else:
-        player.paused ^= True
+    app.player.playpause()
 
 
 @registry.register("stop")
@@ -176,7 +171,7 @@ def _volume(app, value):
     if value[0] in ('+', '-'):
         if len(value) > 1:
             try:
-                change = (int(value[1:]) / 100.0)
+                change = (float(value[1:]) / 100.0)
             except ValueError:
                 return
         else:
@@ -186,7 +181,7 @@ def _volume(app, value):
         volume = app.player.volume + change
     else:
         try:
-            volume = (int(value) / 100.0)
+            volume = (float(value) / 100.0)
         except ValueError:
             return
     app.player.volume = min(1.0, max(0.0, volume))
