@@ -2,13 +2,15 @@
 # Copyright 2013 Simonas Kazlauskas
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from os import path
 
 from gi.repository import Soup
 
+from quodlibet import _
 from quodlibet.plugins.cover import CoverSourcePlugin, cover_dir
 from quodlibet.util.http import download_json
 from quodlibet.util.cover.http import HTTPDownloadMixin
