@@ -3,8 +3,9 @@
 #        2016-17 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from gi.repository import Gtk
 
@@ -146,6 +147,12 @@ class AdvancedPreferences(EventPlugin):
                 ("A (tied) tag for the main window title, e.g. ~title~~people "
                  "(restart required)")))
 
+        rows.append(
+            text_config(
+                "settings", "datecolumn_timestamp_format",
+                "DateColumn timestamp format",
+                "A timestamp format, e.g. %Y%m%d %X "))
+
         for (row, (label, entry, button)) in enumerate(rows):
             label.set_alignment(1.0, 0.5)
             table.attach(label, 0, 1, row, row + 1,
