@@ -3,14 +3,16 @@
 #           2012,2014 Christoph Reiter
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 import os
 import sys
 import subprocess
 
 from gi.repository import Gtk
+from senf import fsn2uri, fsnative
 
 from quodlibet.plugins.songshelpers import any_song, is_a_file
 
@@ -19,11 +21,11 @@ try:
 except ImportError:
     dbus = None
 
+from quodlibet import _
 from quodlibet.plugins.songsmenu import SongsMenuPlugin
 from quodlibet.qltk.msg import ErrorMessage
 from quodlibet.qltk import Icons
 from quodlibet.util.dprint import print_d
-from quodlibet.util.path import is_fsnative, uri_from_path
 
 
 class BrowseError(Exception):
@@ -86,7 +88,7 @@ def browse_folders_thunar(songs, display=""):
         # open each folder and select the first file we have selected
         for dirname, sub_songs in group_songs(songs).items():
             bus_iface.DisplayFolderAndSelect(
-                uri_from_path(dirname),
+                fsn2uri(dirname),
                 sub_songs[0]("~basename"),
                 display,
                 get_startup_id())
@@ -120,8 +122,8 @@ def show_files_win32(path, files):
     """
 
     assert os.name == "nt"
-    assert is_fsnative(path)
-    assert all(is_fsnative(f) for f in files)
+    assert isinstance(path, fsnative)
+    assert all(isinstance(f, fsnative) for f in files)
 
     from quodlibet.util.windows import open_folder_and_select_items
 
