@@ -216,7 +216,7 @@ class CustomCommands(PlaylistPlugin, SongsMenuPlugin, PluginConfigMixin):
         print_d("Loading saved commands from '%s'..." % filename)
         coms = None
         try:
-            with open(filename) as f:
+            with open(filename, "r", encoding="utf-8") as f:
                 coms = JSONObjectDict.from_json(Command, f.read())
         except (IOError, ValueError) as e:
             print_w("Couldn't parse saved commands (%s)" % e)
