@@ -2,8 +2,9 @@
 # Copyright 2011,2013 Christoph Reiter
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 import json
 import collections
@@ -14,7 +15,7 @@ from xml.dom.minidom import parseString
 from gi.repository import GLib
 
 from quodlibet.util import print_w
-from quodlibet.compat import iteritems, urlencode, Queue, cBytesIO
+from quodlibet.compat import iteritems, urlencode, queue, cBytesIO
 from quodlibet.util.urllib import urlopen, Request
 from .util import get_api_key, GateKeeper
 
@@ -59,9 +60,9 @@ class AcoustidSubmissionThread(threading.Thread):
             "user": get_api_key(),
         })
 
-        urldata = "&".join([basedata] + map(urlencode, urldata))
+        urldata = "&".join([basedata] + list(map(urlencode, urldata)))
         obj = cBytesIO()
-        gzip.GzipFile(fileobj=obj, mode="wb").write(urldata)
+        gzip.GzipFile(fileobj=obj, mode="wb").write(urldata.encode())
         urldata = obj.getvalue()
 
         headers = {
@@ -104,6 +105,7 @@ class AcoustidSubmissionThread(threading.Thread):
                 "bitrate": song("~#bitrate"),
                 "fileformat": song("~format"),
                 "mbid": song("musicbrainz_trackid"),
+                "track": song("title"),
                 "artist": song.list("artist"),
                 "album": song("album"),
                 "albumartist": song("albumartist"),
@@ -262,7 +264,7 @@ class AcoustidLookupThread(threading.Thread):
     def __init__(self, progress_cb):
         super(AcoustidLookupThread, self).__init__()
         self.__progress_cb = progress_cb
-        self.__queue = Queue.Queue()
+        self.__queue = queue.Queue()
         self.__stopped = False
         self.start()
 
@@ -298,7 +300,7 @@ class AcoustidLookupThread(threading.Thread):
 
         urldata = "&".join(req_data)
         obj = cBytesIO()
-        gzip.GzipFile(fileobj=obj, mode="wb").write(urldata)
+        gzip.GzipFile(fileobj=obj, mode="wb").write(urldata.encode())
         urldata = obj.getvalue()
 
         headers = {
@@ -316,7 +318,7 @@ class AcoustidLookupThread(threading.Thread):
         else:
             try:
                 data = response.read()
-                data = json.loads(data)
+                data = json.loads(data.decode())
             except ValueError as e:
                 error = str(e)
             else:
@@ -340,7 +342,7 @@ class AcoustidLookupThread(threading.Thread):
                 timeout = 0.5 / len(results)
                 try:
                     results.append(self.__queue.get(timeout=timeout))
-                except Queue.Empty:
+                except queue.Empty:
                     break
 
             if self.__stopped:
