@@ -2,8 +2,9 @@
 # Copyright 2014 Christoph Reiter
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from contextlib import contextmanager
 
@@ -12,6 +13,7 @@ from gi.repository import Gtk, Pango, Gdk
 from .analyze import FingerPrintPool
 from .acoustid import AcoustidLookupThread
 from .util import get_write_mb_tags, get_group_by_dir
+from quodlibet import _
 from quodlibet.qltk.models import ObjectStore
 from quodlibet.qltk.views import AllTreeView
 from quodlibet.qltk.window import Window
