@@ -2,11 +2,13 @@
 # Copyright 2015 Christoph Reiter
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from mutagen.id3 import ID3
 
+from quodlibet import _
 from quodlibet import app
 from quodlibet import util
 from quodlibet.formats._id3 import ID3File
