@@ -2,8 +2,9 @@
 # Copyright 2011-2016 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 import quodlibet
 from quodlibet import _
@@ -36,7 +37,7 @@ class WebsiteSearch(SongsMenuPlugin):
     PLUGIN_DESC = _("Searches your choice of website using any song tags.\n"
                     "Supports patterns e.g. %(pattern-example)s.") % {
                         "pattern-example":
-                            "https://google.com?q=<~artist~title>"}
+                            "https://google.com?q=&lt;~artist~title&gt;"}
 
     # Here are some starters...
     DEFAULT_URL_PATS = [
