@@ -2,8 +2,9 @@
 # Copyright 2009-2011 Steven Robertson, Christoph Reiter
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 import collections
 import subprocess
@@ -20,6 +21,16 @@ from quodlibet.compat import text_type, number_types, xrange
 def pulse_is_running():
     """Returns whether pulseaudio is running"""
 
+    # If we have a pulsesink we can get the server presence through
+    # setting the ready state
+    element = Gst.ElementFactory.make("pulsesink", None)
+    if element is not None:
+        element.set_state(Gst.State.READY)
+        res = element.get_state(0)[0]
+        element.set_state(Gst.State.NULL)
+        return res != Gst.StateChangeReturn.FAILURE
+
+    # In case we don't have it call the pulseaudio binary
     try:
         subprocess.check_call(["pulseaudio", "--check"])
     except subprocess.CalledProcessError:
