@@ -1,14 +1,16 @@
 # -*- coding: utf-8 -*-
 # Copyright 2005 Joe Wreschnig, Michael Urman
 #           2012 Christoph Reiter
-#           2016 Nick Boultbee
+#          2016-17 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 import os
 import signal
+import socket
 
 import gi
 gi.require_version("Gtk", "3.0")
@@ -19,6 +21,46 @@ from gi.repository import GLib, GObject
 from senf import fsn2bytes, bytes2fsn
 
 from quodlibet.util import gdecode, print_d, print_w
+from quodlibet.compat import urlparse
+
+
+def show_uri(label, uri):
+    """Shows a uri. The uri can be anything handled by GIO or a quodlibet
+    specific one.
+
+    Currently handled quodlibet uris:
+        - quodlibet:///prefs/plugins/<plugin id>
+
+    Args:
+        label (str)
+        uri (str) the uri to show
+    Returns:
+        True on success, False on error
+    """
+
+    parsed = urlparse(uri)
+    if parsed.scheme == "quodlibet":
+        if parsed.netloc != "":
+            print_w("Unknown QuodLibet URL format (%s)" % uri)
+            return False
+        else:
+            return __show_quodlibet_uri(parsed)
+    else:
+        # Gtk.show_uri_on_window exists since 3.22
+        if hasattr(Gtk, "show_uri_on_window"):
+            from quodlibet.qltk import get_top_parent
+            return Gtk.show_uri_on_window(get_top_parent(label), uri, 0)
+        else:
+            return Gtk.show_uri(None, uri, 0)
+
+
+def __show_quodlibet_uri(uri):
+    if uri.path.startswith("/prefs/plugins/"):
+        from .pluginwin import PluginWindow
+        print_d("Showing plugin prefs resulting from URI (%s)" % (uri, ))
+        return PluginWindow().move_to(uri.path[len("/prefs/plugins/"):])
+    else:
+        return False
 
 
 def get_fg_highlight_color(widget):
@@ -120,20 +162,24 @@ def get_menu_item_top_parent(widget):
     return get_top_parent(widget)
 
 
-def find_widgets(container, type_):
-    """Given a container, find all children that are a subclass of type_
+def find_widgets(widget, type_):
+    """Given a widget, find all children that are a subclass of type_
     (including itself)
-    """
 
-    assert isinstance(container, Gtk.Container)
+    Args:
+        widget (Gtk.Widget)
+        type_ (type)
+    Returns:
+        List[Gtk.Widget]
+    """
 
     found = []
 
-    if isinstance(container, type_):
-        found.append(container)
+    if isinstance(widget, type_):
+        found.append(widget)
 
-    for child in container.get_children():
-        if isinstance(child, Gtk.Container):
+    if isinstance(widget, Gtk.Container):
+        for child in widget.get_children():
             found.extend(find_widgets(child, type_))
 
     return found
@@ -245,6 +291,13 @@ def is_accel(event, *accels):
     any of accelerator strings.
 
     example: is_accel(event, "<shift><ctrl>z")
+
+    Args:
+        *accels: one ore more `str`
+    Returns:
+        bool
+    Raises:
+        ValueError: in case any of the accels could not be parsed
     """
 
     assert accels
@@ -259,9 +312,12 @@ def is_accel(event, *accels):
         keyval = ord(chr(keyval).lower())
 
     default_mod = Gtk.accelerator_get_default_mod_mask()
+    keymap = Gdk.Keymap.get_default()
 
     for accel in accels:
         accel_keyval, accel_mod = Gtk.accelerator_parse(accel)
+        if accel_keyval == 0 and accel_mod == 0:
+            raise ValueError("Invalid accel: %s" % accel)
 
         # If the accel contains non default modifiers matching will
         # never work and since no one should use them, complain
@@ -270,6 +326,11 @@ def is_accel(event, *accels):
             print_w("Accelerator '%s' contains a non default modifier '%s'." %
                 (accel, Gtk.accelerator_name(0, non_default) or ""))
 
+        # event.state contains the real mod mask + the virtual one, while
+        # we usually pass only virtual one as text. This adds the real one
+        # so they match in the end.
+        accel_mod = keymap.map_virtual_modifiers(accel_mod)[1]
+
         # Remove everything except default modifiers and compare
         if (accel_keyval, accel_mod) == (keyval, event.state & default_mod):
             return True
@@ -322,14 +383,7 @@ def get_backend_name():
 gtk_version = (Gtk.get_major_version(), Gtk.get_minor_version(),
                Gtk.get_micro_version())
 
-try:
-    pygobject_version = gi.version_info
-except AttributeError:
-    # older gi versions
-    try:
-        pygobject_version = gi._gobject.pygobject_version
-    except AttributeError:
-        pygobject_version = (-1,)
+pygobject_version = gi.version_info
 
 
 def io_add_watch(fd, prio, condition, func, *args, **kwargs):
@@ -348,12 +402,14 @@ def io_add_watch(fd, prio, condition, func, *args, **kwargs):
         return GLib.io_add_watch(fd, condition, func, *args, **kwargs)
 
 
-def add_signal_watch(signal_action):
+def add_signal_watch(signal_action, _sockets=[]):
     """Catches signals which should exit the program and calls `signal_action`
     after the main loop has started, even if the signal occurred before the
     main loop has started.
     """
 
+    # See https://bugzilla.gnome.org/show_bug.cgi?id=622084 for details
+
     sig_names = ["SIGINT", "SIGTERM", "SIGHUP"]
     if os.name == "nt":
         sig_names = ["SIGINT", "SIGTERM"]
@@ -365,35 +421,6 @@ def add_signal_watch(signal_action):
             continue
         signals[id_] = name
 
-    # in case Python catches a signal, wake up the mainloop.
-    # this makes signal handling work with older pygobject/glib (Ubuntu 12.04)
-    # no idea why..
-    rfd, wfd = os.pipe()
-
-    def wakeup_notify(source, condition):
-        # just read and do nothing so we can keep the watch around
-        if condition == GLib.IO_IN:
-            try:
-                os.read(rfd, 1)
-            except EnvironmentError:
-                pass
-            return True
-        else:
-            return False
-
-    try:
-        import fcntl
-    except ImportError:
-        pass
-    else:
-        fcntl.fcntl(wfd, fcntl.F_SETFL, os.O_NONBLOCK)
-
-    signal.set_wakeup_fd(wfd)
-    io_add_watch(rfd, GLib.PRIORITY_HIGH,
-                 GLib.IO_IN | GLib.IO_ERR | GLib.IO_HUP,
-                 wakeup_notify)
-
-    # set a python handler for each signal, used before the mainloop
     for signum, name in signals.items():
         # Before the mainloop starts we catch signals in python
         # directly and idle_add the app.quit
@@ -404,28 +431,31 @@ def add_signal_watch(signal_action):
         print_d("Register Python signal handler: %r" % name)
         signal.signal(signum, idle_handler)
 
+    read_socket, write_socket = socket.socketpair()
+    for sock in [read_socket, write_socket]:
+        sock.setblocking(False)
+        # prevent it from being GCed and leak it
+        _sockets.append(sock)
+
+    def signal_notify(source, condition):
+        if condition & GLib.IOCondition.IN:
+            try:
+                return bool(read_socket.recv(1))
+            except EnvironmentError:
+                return False
+        else:
+            return False
+
     if os.name == "nt":
-        return
-
-    # also try to use the official glib handling if available,
-    # can't hurt I guess
-    unix_signal_add = None
-    if hasattr(GLib, "unix_signal_add"):
-        unix_signal_add = GLib.unix_signal_add
-    elif hasattr(GLib, "unix_signal_add_full"):
-        unix_signal_add = GLib.unix_signal_add_full
+        channel = GLib.IOChannel.win32_new_socket(read_socket.fileno())
     else:
-        print_d("Can't install GLib signal handler, too old gi or wrong OS")
-        return
+        channel = GLib.IOChannel.unix_new(read_socket.fileno())
+    io_add_watch(channel, GLib.PRIORITY_HIGH,
+                 (GLib.IOCondition.IN | GLib.IOCondition.HUP |
+                  GLib.IOCondition.NVAL | GLib.IOCondition.ERR),
+                 signal_notify)
 
-    for signum, name in signals.items():
-
-        def handler(signum):
-            print_d("GLib signal handler activated: %s" % signals[signum])
-            signal_action()
-
-        print_d("Register GLib signal handler: %r" % name)
-        unix_signal_add(GLib.PRIORITY_HIGH, signum, handler, signum)
+    signal.set_wakeup_fd(write_socket.fileno())
 
 
 class ThemeOverrider(object):
