@@ -3,11 +3,13 @@
 #           2013 Christoph Reiter
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from gi.repository import Gtk, Gdk, GLib
 
+from quodlibet import _
 from quodlibet import config
 from quodlibet import qltk
 from quodlibet import util
@@ -301,9 +303,7 @@ class SeekButton(HSlider):
         return True
 
     def __seeked(self, player, song, ms):
-        # If it's not paused, we'll grab it in our next update.
-        if player.paused:
-            self.scale.set_value(ms // 1000)
+        self.scale.set_value(ms / 1000.)
 
     def __scroll(self, widget, event, player):
         self.__lock = True
@@ -329,7 +329,7 @@ class SeekButton(HSlider):
         # When the song is paused GStreamer returns < 1 for position
         # queries, so if it's paused just ignore it.
         if not (player.paused or self.__lock):
-            position = player.get_position() // 1000
+            position = player.get_position() / 1000.
             if (not self.__seekable and
                 position > self.scale.get_adjustment().get_upper()):
                 self.scale.set_range(0, position)
