@@ -3,8 +3,9 @@
 #      2013-2017 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from gi.repository import Gtk
 
@@ -13,9 +14,10 @@ from quodlibet.qltk.pluginwin import PluginWindow
 
 from quodlibet import ngettext, _
 from quodlibet import qltk
+from quodlibet.errorreport import errorhook
 
-from quodlibet.util import print_exc, print_e, print_w
-from quodlibet.qltk.msg import WarningMessage
+from quodlibet.util import print_e, print_w
+from quodlibet.qltk.msg import ConfirmationPrompt
 from quodlibet.qltk.delete import TrashMenuItem, trash_songs
 from quodlibet.qltk.information import Information
 from quodlibet.qltk.properties import SongProperties
@@ -27,60 +29,26 @@ from quodlibet.plugins.songsmenu import SongsMenuPlugin
 from quodlibet.util.songwrapper import ListWrapper, check_wrapper_changed
 
 
-class ConfirmMultiSongInvoke(WarningMessage):
+def confirm_multi_song_invoke(parent, plugin_name, count):
     """Dialog to confirm invoking a plugin with X songs in case X is high"""
-
-    RESPONSE_INVOKE = 1
-
-    def __init__(self, parent, plugin_name, count):
-        title = ngettext("Run the plugin \"%(name)s\" on %(count)d song?",
-                         "Run the plugin \"%(name)s\" on %(count)d songs?",
-                         count) % {"name": plugin_name, "count": count}
-
-        super(ConfirmMultiSongInvoke, self).__init__(
-            get_top_parent(parent),
-            title, "",
-            buttons=Gtk.ButtonsType.NONE)
-
-        self.add_button(_("_Cancel"), Gtk.ResponseType.CANCEL)
-        self.add_icon_button(_("_Run Plugin"), Icons.SYSTEM_RUN,
-                             self.RESPONSE_INVOKE)
-        self.set_default_response(Gtk.ResponseType.CANCEL)
-
-    @classmethod
-    def confirm(cls, parent, plugin_name, count):
-        """Returns if the action was confirmed"""
-
-        resp = cls(parent, plugin_name, count).run()
-        return resp == cls.RESPONSE_INVOKE
+    title = ngettext("Run the plugin \"%(name)s\" on %(count)d song?",
+                     "Run the plugin \"%(name)s\" on %(count)d songs?",
+                     count) % {"name": plugin_name, "count": count}
+    description = ""
+    ok_text = _("_Run Plugin")
+    prompt = ConfirmationPrompt(parent, title, description, ok_text).run()
+    return prompt == ConfirmationPrompt.RESPONSE_INVOKE
 
 
-class ConfirmMultiAlbumInvoke(WarningMessage):
+def confirm_multi_album_invoke(parent, plugin_name, count):
     """Dialog to confirm invoking a plugin with X albums in case X is high"""
-
-    RESPONSE_INVOKE = 1
-
-    def __init__(self, parent, plugin_name, count):
-        title = ngettext("Run the plugin \"%(name)s\" on %(count)d album?",
-                         "Run the plugin \"%(name)s\" on %(count)d albums?",
-                         count) % {'name': plugin_name, 'count': count}
-
-        super(ConfirmMultiAlbumInvoke, self).__init__(
-            get_top_parent(parent),
-            title, "",
-            buttons=Gtk.ButtonsType.NONE)
-
-        self.add_button(_("_Cancel"), Gtk.ResponseType.CANCEL)
-        self.add_icon_button(_("_Run Plugin"), Icons.SYSTEM_RUN,
-                             self.RESPONSE_INVOKE)
-        self.set_default_response(Gtk.ResponseType.CANCEL)
-
-    @classmethod
-    def confirm(cls, parent, plugin_name, count):
-        """Returns if the action was confirmed"""
-
-        resp = cls(parent, plugin_name, count).run()
-        return resp == cls.RESPONSE_INVOKE
+    title = ngettext("Run the plugin \"%(name)s\" on %(count)d album?",
+                     "Run the plugin \"%(name)s\" on %(count)d albums?",
+                     count) % {"name": plugin_name, "count": count}
+    description = ""
+    ok_text = _("_Run Plugin")
+    prompt = ConfirmationPrompt(parent, title, description, ok_text).run()
+    return prompt == ConfirmationPrompt.RESPONSE_INVOKE
 
 
 class SongsMenuPluginHandler(PluginHandler):
@@ -90,11 +58,11 @@ class SongsMenuPluginHandler(PluginHandler):
 
         self.__plugins = []
 
-        self._confirm_multiple_songs = ConfirmMultiSongInvoke.confirm
+        self._confirm_multiple_songs = confirm_multi_song_invoke
         if song_confirmer is not None:
             self._confirm_multiple_songs = song_confirmer
 
-        self._confirm_multiple_albums = ConfirmMultiAlbumInvoke.confirm
+        self._confirm_multiple_albums = confirm_multi_album_invoke
         if album_confirmer is not None:
             self._confirm_multiple_albums = album_confirmer
 
@@ -126,7 +94,7 @@ class SongsMenuPluginHandler(PluginHandler):
                 except:
                     print_e("Couldn't initialise song plugin %s. Stack trace:"
                             % Kind)
-                    print_exc()
+                    errorhook()
         items = [i for i in items if i.initialized]
 
         if items:
@@ -143,7 +111,7 @@ class SongsMenuPluginHandler(PluginHandler):
                         item.connect(
                             'activate', self.__on_activate, item, *args)
                 except:
-                    print_exc()
+                    errorhook()
                     item.destroy()
             menu.append(SeparatorMenuItem())
             prefs = Gtk.MenuItem(label=_("Configure Plugins…"))
@@ -178,7 +146,7 @@ class SongsMenuPluginHandler(PluginHandler):
                 try:
                     plugin = plugin(songs, library)
                 except Exception:
-                    print_exc()
+                    errorhook()
                 else:
                     self.__handle(plugin, plugin, library, songs, parent)
                 return
@@ -196,7 +164,7 @@ class SongsMenuPluginHandler(PluginHandler):
                 try:
                     ret = plugin.plugin_single_song(songs[0])
                 except Exception:
-                    print_exc()
+                    errorhook()
                 else:
                     if ret:
                         return
@@ -210,7 +178,7 @@ class SongsMenuPluginHandler(PluginHandler):
                 try:
                     ret = map(plugin.plugin_song, songs)
                 except Exception:
-                    print_exc()
+                    errorhook()
                 else:
                     if any(ret):
                         return
@@ -218,7 +186,7 @@ class SongsMenuPluginHandler(PluginHandler):
                 try:
                     ret = plugin.plugin_songs(songs)
                 except Exception:
-                    print_exc()
+                    errorhook()
                 else:
                     if ret:
                         return
@@ -235,7 +203,7 @@ class SongsMenuPluginHandler(PluginHandler):
                 try:
                     ret = plugin.plugin_single_album(albums[0])
                 except Exception:
-                    print_exc()
+                    errorhook()
                 else:
                     if ret:
                         return
@@ -243,7 +211,7 @@ class SongsMenuPluginHandler(PluginHandler):
                 try:
                     ret = map(plugin.plugin_album, albums)
                 except Exception:
-                    print_exc()
+                    errorhook()
                 else:
                     if any(ret):
                         return
@@ -251,7 +219,7 @@ class SongsMenuPluginHandler(PluginHandler):
                 try:
                     ret = plugin.plugin_albums(albums)
                 except Exception:
-                    print_exc()
+                    errorhook()
                 else:
                     if ret:
                         return
@@ -277,10 +245,9 @@ class SongsMenu(Gtk.Menu):
         PluginManager.instance.register_handler(cls.plugins)
 
     def __init__(self, library, songs, plugins=True, playlists=True,
-                 queue=True, devices=True, remove=True, delete=False,
+                 queue=True, remove=True, delete=False,
                  edit=True, ratings=True, items=None, accels=True):
         super(SongsMenu, self).__init__()
-
         # The library may actually be a librarian; if it is, use it,
         # otherwise find the real librarian.
         librarian = getattr(library, 'librarian', library)
@@ -355,22 +322,6 @@ class SongsMenu(Gtk.Menu):
             self.append(b)
             b.set_sensitive(can_add and bool(songs))
 
-        if devices:
-            from quodlibet import browsers
-            try:
-                browsers.media
-            except AttributeError:
-                pass
-            else:
-                if browsers.media.MediaDevices in browsers.browsers:
-                    submenu = browsers.media.Menu(songs, library)
-                    b = qltk.MenuItem(_("_Copy to Device"),
-                                      Icons.MULTIMEDIA_PLAYER)
-                    if can_add and len(submenu) > 0 and bool(songs):
-                        b.set_sensitive(True)
-                        b.set_submenu(submenu)
-                        self.append(b)
-
         if remove or delete:
             self.separate()
 
