@@ -4,8 +4,9 @@
 #           2011-2016 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from __future__ import absolute_import
 
@@ -385,6 +386,10 @@ class Playlist(Collection, Iterable):
         name = text_type(name)
         if not name:
             raise ValueError("Playlists must have a name")
+
+        # we require a file library here with masking
+        assert library is None or hasattr(library, "masked")
+
         self.name = name
         self.library = library
         self._list = HashedList()
