@@ -1,31 +1,26 @@
 # -*- coding: utf-8 -*-
 # Copyright 2013 Simonas Kazlauskas
-#           2016 Nick Boultbee
+#        2016-17 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 import json
 
 from gi.repository import Soup, Gio, GLib, GObject
 from gi.repository.GObject import ParamFlags, SignalFlags
 
-if not hasattr(Gio.MemoryOutputStream, 'new_resizable'):
-    raise ImportError(
-        'GLib and gobject-introspection libraries are too old. GLib since ' +
-        '2.36 and gobject-introspection since 1.36 are known to work fine.')
-
 from quodlibet.const import VERSION, WEBSITE
 from quodlibet.util import print_d, print_w
 
 
 PARAM_READWRITECONSTRUCT = \
     ParamFlags.CONSTRUCT_ONLY | ParamFlags.READABLE | ParamFlags.WRITABLE
-SoupStatus = Soup.Status if hasattr(Soup, 'Status') else Soup.KnownStatusCode
 
 
-class DefaultHTTPRequest(GObject.Object):
+class HTTPRequest(GObject.Object):
     """
     Class encapsulating a single HTTP request. These are meant to be sent
     and received only once. Behaviour is undefined otherwise.
@@ -54,9 +49,9 @@ class DefaultHTTPRequest(GObject.Object):
         if message is None:
             raise ValueError('Message may not be None')
 
-        inner_cancellable = Gio.Cancellable.new()
-        super(DefaultHTTPRequest, self).__init__(message=message,
-                                                 cancellable=inner_cancellable)
+        inner_cancellable = Gio.Cancellable()
+        super(HTTPRequest, self).__init__(message=message,
+                                          cancellable=inner_cancellable)
         if cancellable is not None:
             cancellable.connect(lambda *x: self.cancel(), None)
 
@@ -119,15 +114,10 @@ class DefaultHTTPRequest(GObject.Object):
         # If we already have input stream, we can just close it, message
         # will come out as cancelled just fine.
         if self.istream and not self._receive_started:
-            # Read contents from input stream (because otherwise in Soup
-            # <2.44.1, unread data will leak into the next request and it will
-            # become unparsable.
             if not self.istream.is_closed():
-                while self.istream.read_bytes(512, None).get_size():
-                    pass
                 self.istream.close(None)
         else:
-            session.cancel_message(self.message, SoupStatus.CANCELLED)
+            session.cancel_message(self.message, Soup.Status.CANCELLED)
 
     def receive(self):
         """
@@ -157,8 +147,6 @@ class DefaultHTTPRequest(GObject.Object):
                 self.istream.close(None)
                 self.emit('received', ostream)
             except GLib.GError as e:
-                while self.istream.read_bytes(512, None).get_size():
-                    pass
                 self.istream.close(None)
                 self.emit('receive-failure', e)
 
@@ -170,61 +158,6 @@ class DefaultHTTPRequest(GObject.Object):
                                   self.cancellable, spliced, None)
 
 
-class FallbackHTTPRequest(DefaultHTTPRequest):
-    """
-    Fallback code which does not use Gio.InputStream based APIs which are
-    not available before libsoup 2.44 introspection.
-
-    To be used with Soup.SessionAsync instead of regular Soup.Session.
-
-    Unlike DefaultHTTPRequest, keeps downloaded content in memory until
-    the request is completed. Also it keeps downloading the content even if
-    receive function is not called (it does, however, stop if the request is
-    cancelled).
-    """
-    _is_done = False
-
-    def send(self):
-        print_d('Sending request to {0}'.format(self._uri))
-        self.message.get_property('response-body').set_accumulate(False)
-        session.queue_message(self.message, lambda *x: None, None)
-        self.message.connect('got-headers', self._sent)
-        self.message.connect('finished', self._finished)
-
-    def _sent(self, message):
-        if self.cancellable.is_cancelled():
-            return self.emit('send-failure', Exception('Cancelled'))
-        if 300 <= message.get_property('status-code') < 400:
-            return # redirection, wait for another emission of got-headers
-        self.istream = Gio.MemoryInputStream.new()
-        self.message.connect('got-chunk', self._chunk)
-        print_d('Sent request to {0}'.format(self._uri))
-        self.emit('sent', self.message)
-
-    def _chunk(self, message, buffer):
-        self.istream.add_bytes(buffer.get_as_bytes())
-
-    def _finished(self, *args):
-        self._is_done = True
-        self.notify('istream')
-
-    def receive(self):
-        def do_receive(*args):
-            self.disconnect(istr_id)
-            super(FallbackHTTPRequest, self).receive()
-        istr_id = 0
-        if not self._is_done and self.istream:
-            istr_id = self.connect('notify::istream', do_receive)
-        else:
-            do_receive()
-
-    def cancel(self):
-        if self.cancellable.is_cancelled():
-            return False
-        session.cancel_message(self.message, SoupStatus.CANCELLED)
-        super(FallbackHTTPRequest, self).cancel()
-
-
 def download(message, cancellable, callback, data, try_decode=False):
     def received(request, ostream):
         ostream.close(None)
@@ -260,14 +193,6 @@ def download_json(message, cancellable, callback, data):
     download(message, cancellable, cb, None, True)
 
 
-if hasattr(Soup.Session, 'send_finish'):
-    # We're using Soup >= 2.44
-    session = Soup.Session.new()
-    HTTPRequest = DefaultHTTPRequest
-else:
-    print_d('Using fallback HTTPRequest implementation. libsoup is too old')
-    session = Soup.SessionAsync.new()
-    HTTPRequest = FallbackHTTPRequest
-
+session = Soup.Session()
 ua_string = "Quodlibet/{0} (+{1})".format(VERSION, WEBSITE)
 session.set_properties(user_agent=ua_string, timeout=15)
